@@ -20,7 +20,7 @@ use Lemonldap::NG::Manager::_i18n;
 use Lemonldap::NG::Manager::Request;
 use Lemonldap::NG::Common::Conf::Constants;    #inherits
 
-our $VERSION = '1.2.2_01';
+our $VERSION = '1.2.3';
 our ( $stylesheet, $parser );
 
 ## @method void confUpload(ref rdata)
@@ -562,6 +562,9 @@ sub applyTest {
     my ( $res, $msg );
     if ( ref($test) eq 'CODE' ) {
         ( $res, $msg ) = &$test($value);
+        $self->lmLog( "Test returns an error :\n  value=$value\n  msg=$msg",
+            'warn' )
+          unless ($res);
     }
     else {
         $res = ( $value =~ $test ? 1 : 0 );
